#
# spec file for package hyper-v
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define hv_kvp_daemon hv_kvp_daemon
%define hv_vss_daemon hv_vss_daemon
%define hv_fcopy_daemon hv_fcopy_daemon
%define vmbus_bufring vmbus_bufring
%define hv_fcopy_uio_daemon hv_fcopy_uio_daemon
%define include_uapi_linux_hyperv include_uapi_linux_hyperv
%define chardev_kvp vmbus/hv_kvp
%define chardev_vss vmbus/hv_vss
%define chardev_fcopy vmbus/hv_fcopy
%define helper_dir /usr/lib/%name

Name:           hyper-v
ExclusiveArch:  %ix86 x86_64 aarch64
%{?systemd_requires}
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(systemd)
# Due to usage of char device instead of netlink
Conflicts:      kernel < 4.2
Summary:        Microsoft Hyper-V tools
License:        GPL-2.0-only
Supplements:    modalias(dmi:*svnMicrosoftCorporation*pnVirtualMachine*rnVirtualMachine*)
Supplements:    modalias(pci:v00001414d00005353sv*sd*bc*sc*i*)
URL:            http://www.kernel.org
# Arbitrary version number
Version:        9
Release:        3.0.2.1.sr20250601
Source0:        hyper-v.lsvmbus.py
Source7:        hyper-v.compare-with-upstream.sh
Source8:        hyper-v.tools.hv.vmbus_bufring.h
Source9:        hyper-v.include.linux.hyperv.h
Source10:       hyper-v.tools.hv.hv_kvp_daemon.c
Source11:       hyper-v.tools.hv.vmbus_bufring.c
Source12:       hyper-v.tools.hv.hv_vss_daemon.c
Source13:       hyper-v.tools.hv.hv_fcopy_uio_daemon.c
Source14:       hyper-v.tools.hv.hv_fcopy_daemon.c
Source20:       hyper-v.tools.hv.hv_get_dhcp_info.sh
Source21:       hyper-v.tools.hv.hv_get_dns_info.sh
Source22:       hyper-v.tools.hv.hv_set_ifconfig.sh

Patch0:         hyper-v.kvp.gethostname.patch

%description
This package contains the Microsoft Hyper-V tools.

%prep
%setup -Tc
cp -vL %{S:8} %vmbus_bufring.h
cp -vL %{S:9} %include_uapi_linux_hyperv.h
cp -vL %{S:10} .
cp -vL %{S:11} %vmbus_bufring.c
cp -vL %{S:12} %hv_vss_daemon.c
cp -vL %{S:13} %hv_fcopy_uio_daemon.c
cp -vL %{S:14} %hv_fcopy_daemon.c
%patch -P 0 -p1
mv `basename %{S:10}` %hv_kvp_daemon.c

%build
sed -i~ '/#include <linux.hyperv.h>/d' %hv_kvp_daemon.c
sed -i~ '/#include <linux.hyperv.h>/d' %hv_vss_daemon.c
sed -i~ '/#include <linux.hyperv.h>/d' %hv_fcopy_uio_daemon.c
sed -i~ '/#include <linux.hyperv.h>/d' %hv_fcopy_daemon.c
gcc \
	$RPM_OPT_FLAGS \
	-Wno-unused-variable \
	-Wno-pointer-sign \
	-D_GNU_SOURCE \
	-g \
	%hv_kvp_daemon.c \
	-include %include_uapi_linux_hyperv.h \
	-DCN_KVP_IDX=0x9 \
	-DCN_KVP_VAL=0x1 \
	-DKVP_SCRIPTS_PATH= \
	-pthread \
	-o %hv_kvp_daemon
gcc \
	$RPM_OPT_FLAGS \
	-Wno-unused-variable \
	-Wno-pointer-sign \
	-D_GNU_SOURCE \
	-g \
	%hv_vss_daemon.c \
	-include %include_uapi_linux_hyperv.h \
	-DCN_VSS_IDX=0xa \
	-DCN_VSS_VAL=0x1 \
	-o %hv_vss_daemon
gcc \
	$RPM_OPT_FLAGS \
	-Wno-unused-variable \
	-Wno-pointer-sign \
	-D_GNU_SOURCE \
	-g \
	%hv_fcopy_daemon.c \
	-include %include_uapi_linux_hyperv.h \
	-o %hv_fcopy_daemon

%ifarch %ix86 x86_64
gcc \
	$RPM_OPT_FLAGS \
	-Wno-unused-variable \
	-Wno-pointer-sign \
	-Wno-address-of-packed-member \
	-D_GNU_SOURCE \
	-g \
	%vmbus_bufring.c \
	%hv_fcopy_uio_daemon.c \
	-include %include_uapi_linux_hyperv.h \
	-o %hv_fcopy_uio_daemon
%endif

%install
# It is not a callable app anyway, so move it out of the way
bindir=%helper_dir/bin
mkdir -p %buildroot${bindir}
mkdir -p %buildroot%_sbindir
install -m755 %hv_kvp_daemon %buildroot${bindir}
install -m755 %hv_vss_daemon %buildroot${bindir}
install -m755 %hv_fcopy_daemon %buildroot${bindir}
%ifarch %ix86 x86_64
install -m755 %hv_fcopy_uio_daemon %buildroot${bindir}
%endif
cp -avL %{S:0} %buildroot%_sbindir/lsvmbus
chmod 0755 %buildroot%_sbindir/lsvmbus
cp -avL %{S:20} %buildroot${bindir}/hv_get_dhcp_info
cp -avL %{S:21} %buildroot${bindir}/hv_get_dns_info
cp -avL %{S:22} %buildroot${bindir}/hv_set_ifconfig
chmod 755 %buildroot${bindir}/*
d=%buildroot%_unitdir
mkdir -vp ${d}
#
tee ${d}/%hv_kvp_daemon.service <<EOF
# started via %_udevrulesdir/%name.rules
[Unit]
Description=Hyper-V KVP Daemon
After=local-fs.target
ConditionVirtualization=microsoft
ConditionPathExists=/dev/%chardev_kvp

[Service]
Environment="PATH=${bindir}:/usr/sbin:/usr/bin:/sbin:/bin"
ExecStart=${bindir}/%hv_kvp_daemon --no-daemon
Restart=on-failure

[Install]
WantedBy=default.target
EOF
#
tee ${d}/%hv_vss_daemon.service <<EOF
# started via %_udevrulesdir/%name.rules
[Unit]
Description=Hyper-V VSS Daemon
ConditionVirtualization=microsoft
ConditionPathExists=/dev/%chardev_vss

[Service]
ExecStart=${bindir}/%hv_vss_daemon --no-daemon
Restart=on-failure

[Install]
WantedBy=default.target
EOF
#
tee ${d}/%hv_fcopy_daemon.service <<EOF
# started via %_udevrulesdir/%name.rules
[Unit]
Description=Hyper-V host to guest file copy daemon
ConditionVirtualization=microsoft
ConditionPathExists=/dev/%chardev_fcopy

[Service]
ExecStart=${bindir}/%hv_fcopy_daemon --no-daemon
Restart=on-failure

[Install]
WantedBy=default.target
EOF
#
tee ${d}/%hv_fcopy_uio_daemon.service <<EOF
# started via %_udevrulesdir/%name.rules
[Unit]
Description=Hyper-V host to guest UIO file copy daemon
ConditionVirtualization=microsoft
ConditionPathExists=/sys/bus/vmbus/drivers/uio_hv_generic/new_id
ConditionPathExists=!/dev/%chardev_fcopy

[Service]
ExecStartPre=/bin/sh -c 'set -e;echo 34d14be3-dee4-41c8-9ae7-6b174977c192 > /sys/bus/vmbus/drivers/uio_hv_generic/new_id'
ExecStart=${bindir}/%hv_fcopy_uio_daemon --no-daemon
Restart=on-failure

[Install]
WantedBy=default.target
EOF
#
#
#
d=%buildroot%_udevrulesdir
mkdir -vp ${d}
tee ${d}/%name.rules <<EOF
ACTION=="add", KERNEL=="%chardev_kvp", TAG+="systemd", ENV{SYSTEMD_WANTS}+="%hv_kvp_daemon.service"
ACTION=="add", KERNEL=="%chardev_vss", TAG+="systemd", ENV{SYSTEMD_WANTS}+="%hv_vss_daemon.service"
ACTION=="add", KERNEL=="%chardev_fcopy", TAG+="systemd", ENV{SYSTEMD_WANTS}+="%hv_fcopy_daemon.service"
ACTION=="add", SUBSYSTEM=="vmbus", ATTRS{class_id}=="{34d14be3-dee4-41c8-9ae7-6b174977c192}", RUN{builtin}+="kmod load uio_hv_generic", TAG+="systemd", ENV{SYSTEMD_WANTS}+="%hv_fcopy_uio_daemon.service"
EOF
#
#
helper=inst_sys.sh
tee %buildroot${bindir}/${helper} <<'_EOF_'
#!/bin/bash
# Starting daemons via RUN== in udev rules is not supported.
# In inst-sys systemd is not used, so start all daemons manually.
bindir=%helper_dir/bin
declare -a helpers
test -c /dev/%chardev_kvp && helpers+=(%hv_kvp_daemon)
test -c /dev/%chardev_vss && helpers+=(%hv_vss_daemon)
if test -c /dev/%chardev_fcopy
then
	helpers+=(%hv_fcopy_daemon)
else
	modprobe -v uio_hv_generic
	if test -f /sys/bus/vmbus/drivers/uio_hv_generic/new_id
	then
		echo '34d14be3-dee4-41c8-9ae7-6b174977c192' > /sys/bus/vmbus/drivers/uio_hv_generic/new_id
		helpers+=(%hv_fcopy_uio_daemon)
	fi
fi
if test -d /sys/bus/vmbus/devices
then
	export PATH=${bindir}:$PATH
	echo -n "Starting hyper-v helpers:"
	for i in "${helpers[@]}"
	do
		if mkdir /run/$i
		then
			echo -n " $i"
			$i < /dev/null &
		fi
	done
	echo " ... done"
fi
_EOF_
chmod 755 %buildroot${bindir}/${helper}
#
%?python3_fix_shebang

%files
%_unitdir/*
%_udevrulesdir/*
%_sbindir/*
%helper_dir

# the relevant part is systemctl daemon-reload, due to udev triggers
%post
%service_add_post %hv_kvp_daemon %hv_vss_daemon %hv_fcopy_daemon %hv_fcopy_uio_daemon
%postun
%service_del_postun_without_restart %hv_kvp_daemon %hv_vss_daemon %hv_fcopy_daemon %hv_fcopy_uio_daemon

%changelog
* Fri Jun  6 2025 ohering@suse.de
- Enable debug logs for hv_kvp_daemon (a9c0b33e) (bsc#1244154)
* Wed Jan  1 2025 ohering@suse.de
- update route parsing in kvp daemon (9bbb8a07)
- reduce resource usage in hv_kvp_daemon (175c71c2)
- reduce resouce usage in hv_get_dns_info helper (a4d024fe)
- hv_kvp_daemon: Pass NIC name to hv_get_dns_info as well (07dfa6e8)
- terminate fcopy daemon if read from uio fails (a9640fcd)
- change permissions of NetworkManager configuration file (91ae69c7)
- Fix a complier warning in the fcopy uio daemon (cb1b78f1)
- remove obsolete kvptest.ps1.txt which failed since a decade
- remove obsolete rpm postinstall code for SLE11SP2
* Tue Oct 22 2024 ohering@suse.de
- Add memory allocation check in hv_fcopy_start (94e86b17)
- suppress the invalid warning for packed member alignment (207e03b0)
- Add new fcopy application based on uio driver (82b0945c)
- Add vmbus_bufring (45bab4d7)
- kvp: Handle IPv4 and Ipv6 combination for keyfile format (f971f6dd)
- kvp: Some small fixes for handling NM keyfiles (c3803203)
- kvp: Support for keyfile based connection profile (42999c90)
- kvp: remove unnecessary (void*) conversions (22589542)
- Remove an extraneous "the" (f15f39fa)
- change http to https in hv_kvp_daemon.c (fa52a4b2)
- replace the copy of include/linux/hyperv.h with include/uapi/linux/hyperv.h (6de74d10)
- merge individual udev rules files into a single rules file
- package only files, not directories already owned by filesystem.rpm
- remove braces from rpm spec macros
- remove obsolete Group tag
- replace RPM_BUILD_ROOT with buildroot
- use a meaningful name for the UAPI include file
- use a meaningful variable name for ifcfg in hv_set_ifconfig.sh
* Tue Apr 23 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Aug 20 2020 ohering@suse.de
- Allow daemon restart again (bsc#1116957)
  Since some time the kernel moved from netlink sockets to char
  devices, which is supposed to handle a connection reopen for the
  kernel<->daemon interface
* Wed Jul 22 2020 ohering@suse.de
- Remove dependency to network-online.target now that gethostname
  is used in kvp_daemon (bsc#1174443, bsc#1174444)
- Reopen the devices if read() or write() returns errors (9fc3c01a)
- Use either python2 or python3 for lsvmbus (bsc#1093910)
- Remove sysv init scripts
* Wed Jul 22 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Enable build on aarch64
* Thu Feb 20 2020 ohering@suse.de
- Revert previous non-upstream change for async name resolution
  Just use gethostname via hyper-v.kvp.gethostname.patch (bsc#1100758)
* Fri Nov 29 2019 ohering@suse.de
- Update lsvmbus interpreter from python(1) to python3(1) again
  because only SLE12 lacked proper python3 support (bsc#1093910)
* Wed Nov 27 2019 ohering@suse.de
- async name resolution in kvp_daemon (bsc#1100758)
- kvp: eliminate 'may be used uninitialized' warning (89eb4d8d)
- fix typos in toolchain (2d35c660)
- fixed Python pep8/flake8 warnings for lsvmbus (5912e791)
- Replace GPLv2 boilerplate/reference with SPDX (43aa3132)
- Fix a warning of buffer overflow with gcc 8.0.1 (4fcba780)
* Tue Oct  9 2018 ohering@suse.de
- fcopy: set 'error' in case an unknown operation was requested (c2d68afb)
* Mon Oct  8 2018 ohering@suse.de
- Update lsvmbus interpreter from python3(1) to python(1)
  because SLE12 lacks python3 support (bsc#1093910)
* Tue Sep 25 2018 ohering@suse.de
- vss: fix loop device detection (07136793)
- Fix IP reporting by KVP daemon with SRIOV (4ba63412)
- Fix a bug in the key delete code (86503bd3)
- fix compiler warnings about major/target_fname (1330fc35)
- PRIVATE hyper-v.compare-with-upstream.sh
* Thu Aug  2 2018 schwab@suse.de
- hyper-v.tools.hv.hv_vss_daemon.c: Include <sys/sysmacros.h> for major
* Tue May 22 2018 ohering@suse.de
- Update lsvmbus interpreter from env(1) to python3(1) (bsc#1093910)
* Mon Jan  8 2018 ohering@suse.de
- update buffer handling in hv_fcopy_daemon
- remove unnecessary header files and netlink related code
- Avoid reading past allocated blocks from KVP file (bnc#1087658)
- fix snprintf warning in kvp_daemon
- properly handle long paths
- kvp: configurable external scripts path
- vss: Thaw the filesystem and continue if freeze call has timed out
- vss: Skip freezing filesystems backed by loop
* Wed Jun 28 2017 ohering@suse.de
- Check VSS daemon is listening before a hot backup (bnc#1029693)
- fix a compile warning in snprintf
- kvp: ensure kvp device fd is closed on exec
- lsvmbus: add pci pass-through UUID
* Wed May  4 2016 ohering@suse.de
- add Conflicts with kernel < 4.2 (fate#320485)
- vss: fix the write()'s argument: error -> vss_msg
- remove repeated HV_FCOPY string
- report ENOSPC errors in hv_fcopy_daemon
- fcopy: full handshake support
- vss: full handshake support
- vss: use misc char device to communicate with kernel
- kvp: use misc char device to communicate with kernel
* Fri Sep 18 2015 ohering@suse.de
- add a python script lsvmbus to list VMBus devices (fate#315887)
* Thu Apr 30 2015 ohering@suse.de
- hv: hypervvssd: call endmntent before call setmntent again
- remove unused bytes_written from kvp_update_file()
- address compiler warnings for hv_kvp_daemon.c
- kvp_daemon: make IPv6-only-injection work
- address compiler warnings for hv_fcopy_daemon.c
- do not add redundant '/' in hv_start_fcopy()
* Thu Apr 16 2015 ohering@suse.de
- Add runlevel script for fcopy daemon in SLE11 (bnc#926534)
* Mon Jan 12 2015 ohering@suse.de
- Check return value of setsockopt call
- Improve error logging in VSS daemon.
- Check return value of poll call
- Properly pack the data for file copy functionality
- make struct hv_do_fcopy match Hyper-V host messages
* Wed Dec 17 2014 ohering@suse.de
- Start hv_kvp_daemon after network-online.target (bnc#910353)
- ignore ENOBUFS and ENOMEM in the KVP daemon
- vssdaemon: skip all filesystems mounted readonly (bnc#909864)
- vssdaemon: report freeze errors
* Tue Nov 25 2014 ohering@suse.de
- introduce -n/--no-daemon option (fate#317533)
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashisms in pre/post scripts
* Tue Sep 30 2014 ohering@suse.de
- vssdaemon: ignore the EBUSY on multiple freezing the same
  partition (bnc#899204)
* Tue Jul  1 2014 ohering@suse.de
- fix file overwriting of hv_fcopy_daemon
* Mon May 26 2014 ohering@suse.de
- copy mask2pfxlen from /etc/sysconfig/network/scripts/functions
  to hv_set_ifconfig (bnc#879256)
* Wed May 21 2014 ohering@suse.de
- Start hyper-v helpers manually with helper script in inst-sys
* Thu Apr 10 2014 ohering@suse.de
- Handle the case when the target file exists correctly in hv_fcopy_daemon
- vssdaemon: Ignore VFAT mounts during the Freeze operation
* Sun Mar  2 2014 ohering@suse.de
- Package /usr/lib/udev to fix build error
* Wed Feb 12 2014 ohering@suse.de
- Update hv_fcopy_daemon, kernel name changed to /dev/vmbus/hv_fcopy
* Thu Jan 23 2014 ohering@suse.de
- Start daemons on demand via udev rules because the guest services
  are optional.
- If systemd is used daemons live in libdir, they are not usercallable apps
* Thu Jan 16 2014 ohering@suse.de
- Add hv_fcopy_daemon for post 13.1 releases (fate#315887)
  hyper-v.tools.hv.hv_fcopy_daemon.c
* Wed Dec 18 2013 ohering@suse.de
- Use native systemd services for post 13.1 releases
* Sun Sep  8 2013 ohering@suse.de
- Update Supplements: modalias(dmi:*)
* Mon Aug 12 2013 ohering@suse.de
- Skip restart_on_update with old hyper-v.rpms while old
  kernel is running (bnc#770763)
* Wed Aug  7 2013 ohering@suse.de
- cache FQDN in kvp_daemon to avoid timeouts (bnc#828714)
- use full nlmsghdr in netlink_send
- correct payload size in netlink_send
- use single send+recv buffer
- log errors to syslog in kvp_set_ip_info
- check return value of system in hv_kvp_daemon
- in kvp_set_ip_info free mac_addr right after usage
- check return value of daemon to fix compiler warning.
* Thu Aug  1 2013 ohering@suse.de
- Fix send/recv buffer allocation (bnc#828714)
* Wed Jul 24 2013 ohering@suse.de
- set BOOTPROTO=static if any IPADDR/IP6ADDR was passed to
  hv_set_ifconfig and dhcp is disabled
* Mon Jul 15 2013 ohering@suse.de
- update hv_kvp_daemon (merge 0783d72fa from v3.9-rc1)
  Fix how ifcfg-* file is created
* Mon Jul 15 2013 ohering@suse.de
- update hv_kvp_daemon (changes up to 3.11-rc1):
  Improve error logging in KVP daemon.
  Fix file descriptor leaks
  Check retrun value of strchr call
  Check return value of poll call
  Check return value of setsockopt call
  daemon should check type of received Netlink msg
  daemon setsockopt should use options macros
  daemon should subscribe only to CN_KVP_IDX group
* Mon Jul 15 2013 ohering@suse.de
- Fix a bug in IPV6 subnet enumeration (bnc#828714)
* Tue Mar 26 2013 ohering@suse.de
- Update hv_vss_daemon (bnc#811033)
* Fri Mar 22 2013 ohering@suse.de
- add hv_vss_daemon (fate#314921)
  helper to support host initiated backup
* Fri Mar 22 2013 ohering@suse.de
- build hv_kvp_daemon with -D_GNU_SOURCE to get O_CLOEXEC
* Fri Mar 22 2013 ohering@suse.de
- update hv_kvp_daemon
  Use CLOEXEC when opening kvp_pool files
  Fix permissions of created directory and files
  Fix /var subdirectory (move state files from /var/opt to /var/lib)
  Fix string types
* Tue Nov 27 2012 ohering@suse.de
- update hv_set_ifconfig, use single index for static ipv4/ipv6 [bnc#790469]
* Sun Nov 25 2012 ohering@suse.de
- update hv_set_ifconfig further to work with our ifcfg [bnc#790469]
* Thu Nov 22 2012 ohering@suse.de
- update hv_get_dhcp_info to work with our ifcfg [bnc#790469]
- remove cat usage from hv_get_dns_info
- add quoting to hv_set_ifconfig to make it more robust
* Mon Nov 12 2012 ohering@suse.de
- remove code to build kmp, it was not enabled because the
  drivers are now in kernel since a long time. [bnc#676890]
* Thu Nov  8 2012 ohering@suse.de
- Netlink source address validation allows DoS [bnc#791605, CVE-2012-5532]
  bugfix for recvfrom check from bnc#761200
* Fri Oct 26 2012 ohering@suse.de
- update hv_set_ifconfig to work with our ifcfg
* Sat Oct 13 2012 ohering@suse.de
- update hv_kvp_daemon
  Return the full kernel version
  Don't return loopback addresses
* Thu Oct  4 2012 ohering@suse.de
- bump to version 4
- update kv_kvp_daemon to 3.7-rc1 state [fate#314441]
  support KVP IP Injection, helper scripts go to /usr/lib/hyper-v/bin:
  hv_get_dhcp_info, hv_get_dns_info, hv_set_ifconfig
- remove usage of absolute paths in runlevel script
* Tue Sep  4 2012 ohering@suse.de
- remove restart_on_update in postun section
  the daemon can not be restarted at this point, and the new daemon
  may not be 100 percent compatible with the currently running
  kernel [bnc#770763]
* Wed May 16 2012 ohering@suse.de
- check origin of netlink messages, use recvfrom() [bnc#761200, CVE-2012-2669]
* Wed May  2 2012 ohering@suse.de
- update insserv part, see comments in OBS submit request #112701
* Tue Mar 27 2012 ohering@suse.de
- add kvptest.ps1.txt to docs, a PowerShell script to verify KVP
* Mon Mar 26 2012 ohering@suse.de
- update hv_kvp_daemon to 3.4-rc1 state
  use a copy linux/hyperv.h to compile the daemon
* Thu Dec  8 2011 ohering@suse.de
- do not package modprobe.conf rule in main package
  prevents loading of ata_piix which is required for cdrom access
* Fri Nov 18 2011 ohering@suse.de
- add Supplements to install package if dmi matches [bnc#731198]
* Thu Sep  1 2011 ohering@suse.de
- disable hyper-v-kmp
  hv_storvsc handles now IDE and SCSI disks and ata_piix is
  compiled into the kernel in SLE12, so the modprobe.conf rules
  have no meaning anymore
* Tue Jul 26 2011 ohering@suse.de
- update hv_kvp_daemon: Cleanup kvp_get_domain_name(). If
  getaddrinfo() fails, deal with it properly (this can happen if no
  IP address has been assigned).  Also, don't specify a specific
  service in the call to getaddrinfo() to make this code as generic
  as possible.
* Sun Jul 24 2011 ohering@suse.de
- update hv_kvp_daemon: The current win7 host does not like it when
  we return the complete kernel release information. Conform to
  what the host expects.
* Fri Jun 17 2011 ohering@suse.de
- update preun, stop_on_removal requires an argument
* Fri Jun 17 2011 ohering@suse.de
- remove get_release_number.sh, which was added by accident
- bump version number to 2
* Fri Jun 17 2011 ohering@suse.de
- catch errors from daemon()
* Fri Jun 17 2011 ohering@suse.de
- update postun to run restart_on_update
- use rpmmacro for daemon name
* Fri Jun 17 2011 ohering@suse.de
- update postin to work in / again when running insserv macro
* Thu Jun 16 2011 ohering@suse.de
- Update version number to 1 so kernel.rpm can obsolete
  the old kmp packages
* Thu Jun 16 2011 ohering@suse.de
- enable hv_kvp_daemon if run in a hv guest [fate#312213]
* Thu Apr 21 2011 ohering@suse.de
- add hv_kvp_daemon to provide system infos to hypervisor [bnc#685189]
  this enables the hyper-v main package
* Sat Apr 16 2011 ohering@suse.de
- Require at least kernel-default 2.6.32.27 for an empty KMP.
* Fri Apr 15 2011 ohering@suse.de
- actually keep the KMP packages with just the modprobe.conf file
* Thu Mar 31 2011 ohering@suse.de
- make building of kernel modules optional [bnc#676890]
  the hv*.ko drivers exist in two places, kernel-default and this
  KMP package. Both can get out of sync, then mkinitrd will use
  (the possible outdated) drivers from this KMP package.
  disable building drivers per default, keep only the
  hyperv_pvdrivers.conf
- mark hyperv_pvdrivers.conf as config to preserve local
  modifications done by the sysadmin
* Thu Feb 24 2011 meissner@suse.de
- also add hv_timesource to Modules.supported [bnc#650748]
* Tue Jan  4 2011 meissner@suse.de
- add hv_utils to Modules.supported [bnc#650748]
* Wed Apr 28 2010 kukuk@suse.de
- Next update of hyperv_pvdrivers.conf [bnc#600212]
* Tue Apr 27 2010 kukuk@suse.de
- hyperv_pvdrivers.conf: fix syntax error
* Tue Apr 27 2010 ksrinivasan@novell.com
- Update hyperv_pvdrivers.conf config file
* Mon Apr 26 2010 kukuk@suse.de
- Add hyperv_pvdrivers.conf modprobe config file
* Fri Mar  5 2010 mmarek@suse.cz
- Packaged drivers/staging/hv as a standalone KMP (bnc#585651).
